/*******************************************************************************
* File Name: PumpSensor_timeout.c
* Version 1.0
*
* Description:
*  This file provides the source code to the API for the PumpSensor_timeout
*  component
*
********************************************************************************
* Copyright 2016-2017, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "PumpSensor_timeout.h"

/** Indicates whether or not the PumpSensor_timeout has been initialized. 
*  The variable is initialized to 0 and set to 1 the first time 
*  PumpSensor_timeout_Start() is called. This allows the Component to 
*  restart without reinitialization after the first call to 
*  the PumpSensor_timeout_Start() routine.
*/
uint8_t PumpSensor_timeout_initVar = 0U;

/** The instance-specific configuration structure. This should be used in the 
*  associated PumpSensor_timeout_Init() function.
*/ 
cy_stc_tcpwm_counter_config_t const PumpSensor_timeout_config =
{
        .period = 300000UL,
        .clockPrescaler = 5UL,
        .runMode = 1UL,
        .countDirection = 1UL,
        .compareOrCapture = 0UL,
        .compare0 = 0UL,
        .compare1 = 16384UL,
        .enableCompareSwap = false,
        .interruptSources = 1UL,
        .captureInputMode = 0UL,
        .captureInput = CY_TCPWM_INPUT_CREATOR,
        .reloadInputMode = 3UL,
        .reloadInput = CY_TCPWM_INPUT_CREATOR,
        .startInputMode = 3UL,
        .startInput = CY_TCPWM_INPUT_CREATOR,
        .stopInputMode = 3UL,
        .stopInput = CY_TCPWM_INPUT_CREATOR,
        .countInputMode = 3UL,
        .countInput = CY_TCPWM_INPUT_CREATOR,
};


/*******************************************************************************
* Function Name: PumpSensor_timeout_Start
****************************************************************************//**
*
*  Calls the PumpSensor_timeout_Init() when called the first time and enables 
*  the PumpSensor_timeout. For subsequent calls the configuration is left 
*  unchanged and the component is just enabled.
*
* \globalvars
*  \ref PumpSensor_timeout_initVar
*
*******************************************************************************/
void PumpSensor_timeout_Start(void)
{
    if (0U == PumpSensor_timeout_initVar)
    {
        (void)Cy_TCPWM_Counter_Init(PumpSensor_timeout_HW, PumpSensor_timeout_CNT_NUM, &PumpSensor_timeout_config); 

        PumpSensor_timeout_initVar = 1U;
    }

    Cy_TCPWM_Enable_Multiple(PumpSensor_timeout_HW, PumpSensor_timeout_CNT_MASK);
    
    #if (PumpSensor_timeout_INPUT_DISABLED == 7UL)
        Cy_TCPWM_TriggerStart(PumpSensor_timeout_HW, PumpSensor_timeout_CNT_MASK);
    #endif /* (PumpSensor_timeout_INPUT_DISABLED == 7UL) */    
}


/* [] END OF FILE */
