/* ========================================
 *
 * Copyright AP Engineering, 2018
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your AP Engineering.
 *
 * ========================================
*/

#include "project.h"
#include "stdio_user.h"
#include <stdio.h>
#include <string.h>
#include <math.h>

#include "FreeRTOSConfig.h"
#include "FreeRTOS.h" 
#include "task.h" 
#include "queue.h"

#include "UART_commands.h"
#include "Error_Debug.h"

#define STEP_PWM_CLOCK_FREQ 10000000

/*******************************************************************************
*        Global variables
*******************************************************************************/
QueueHandle_t UART_commands_Queue = NULL;

void ISR_PumpSensor_timeout(void)
{
    // Clear the terminal count interrupt
    PumpSensor_timeout_ClearInterrupt( CY_TCPWM_INT_ON_TC );
    
    ERROR_MSG( "Bad pump sensor.\r\n" )
    REPORT_ERROR()
    handle_error();
}

int main(void)
{   

    init_UART();  
    // Enable the interrupt
    NVIC_EnableIRQ( UART_SCB_IRQ_cfg.intrSrc ); 
        
    displayCommandMenu();
        
     // Init TCPWM for the pump sensor timeout
    PumpSensor_timeout_Init( &PumpSensor_timeout_config );
    
    // Register the interrupt
    cy_en_sysint_status_t sysInterruptStatus = Cy_SysInt_Init( 
            &PumpSensor_timeout_Interrupt_cfg, 
            ISR_PumpSensor_timeout 
            );
    if( sysInterruptStatus != CY_SYSINT_SUCCESS )
    {
        REPORT_ERROR()
        handle_error();
    }
    // Enable the interrupt  
    NVIC_ClearPendingIRQ( PumpSensor_timeout_Interrupt_cfg.intrSrc );
    NVIC_EnableIRQ( PumpSensor_timeout_Interrupt_cfg.intrSrc );

    /* Enable global interrupts. */
    __enable_irq();   
    
    uint16_t prescale = pow( 2.0, (double)( PumpSensor_timeout_config.clockPrescaler ) );
    uint32_t count = 4 * ( STEP_PWM_CLOCK_FREQ / prescale );
    PumpSensor_timeout_SetPeriod( count );
    
    PumpSensor_timeout_Start();
    
    xTaskCreate( UART_MenuTask, "UART_MenuTask", 400, NULL, 4, 0 );
    vTaskStartScheduler();
    
    for (;;){}

}

/* [] END OF FILE */
